@@ -1,14 +1,15 @@
 import re
-import imp
 import time
 import datetime
+import importlib
 import threading
-from typing import Any, cast, Dict, List, Tuple, Callable, Optional, Sequence
+from typing import Any, Dict, List, Tuple, Callable, Optional, Sequence
 
 from typing_extensions import TypedDict
 
 from django.apps import apps
 from django.core.management import call_command
+from django.utils.module_loading import module_has_submodule
 
 from .task import task
 from .types import QueueName
@@ -50,8 +51,15 @@ class CronScheduler(threading.Thread):
         )
 
         while True:
-            # This will run until the process terminates.
-            self.tick(backend)
+            try:
+                # This will run until the process terminates.
+                self.tick(backend)
+            except Exception:
+                # Log that something went wrong, but ensure that this thread
+                # carries on running. Otherwise a single network error talking
+                # to a backend can result in the cron scheduler dying until a
+                # human notices that things aren't running.
+                self.logger.exception("Error during tick")
 
             # Sleep until the next second boundary. This corrects for skew
             # caused by the accumulation of tick() runtime.
@@ -125,24 +133,19 @@ def get_cron_config() -> Sequence[CronConfig]:
         return lambda x: x in t_parts
 
     for app_config in apps.get_app_configs():
-        app = app_config.name
+        # Adapted from django.utils.module_loading.autodiscover_modules
         try:
-            # __import__ will break with anything other than a str object(!),
-            # including e.g. unicode. So force to a str.
-            part = str(app.split('.')[-1])
+            mod = importlib.import_module(f'{app_config.name}.cron')
+        except Exception:
+            if module_has_submodule(app_config.module, 'cron'):
+                # The module exists, so the error was something it did -- bubble the error.
+                raise
+            else:
+                # No module, move on.
+                continue
 
-            app_path = __import__(app, {}, {}, [part]).__path__
-        except AttributeError:
-            continue
-
-        try:
-            imp.find_module('cron', app_path)
-        except ImportError:
-            continue
-
-        mod = __import__('{}.cron'.format(app), fromlist=(app,))
-
-        for row in cast(List[CronConfig], mod.CONFIG):
+        app_cron_config: List[CronConfig] = mod.CONFIG
+        for row in app_cron_config:
             row['min_matcher'] = get_matcher(0, 59, row.get('minutes'))
             row['hour_matcher'] = get_matcher(0, 23, row.get('hours'))
             row['day_matcher'] = get_matcher(1, 7, row.get('days', '*'))
